@@ -75,8 +75,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil alarms";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ialarms";
+#endif
 static char   fdebug    = 0;
 static char   fbmctam   = 0;
 static char   fpicmg    = 0;
