@@ -2681,7 +2681,7 @@ main(int argc, char **argv)
    }  /*endif not readonly*/
 
 do_exit:
-   if (fd_bmc != stdout) fclose(fd_bmc);
+   if (fd_bmc != NULL && fd_bmc != stdout) fclose(fd_bmc);
    ipmi_close_();
    if (nerrs > 0) {
 	printf("Warning: %d ok, %d errors occurred, last error = %d\n",ngood,nerrs,lasterr);
