@@ -680,8 +680,6 @@ sig_abort(int sig)
 {
    static int sig_aborting = 0;
    int rv;
-   // uchar buf_rs[4]; 
-   // uchar *cmd_rs;
 
    if (sig_aborting == 0) {
      sig_aborting = 1;
@@ -1057,7 +1055,7 @@ static int _send_lan_cmd(SockType s, uchar *pcmd, int scmd, uchar *presp,
     }
     clen = hlen + msglen;
     if (clen > sizeof(cbuf)) {
-        fprintf(fpdbg,"message size %d > buffer size %d\n",clen,sizeof(cbuf));
+        fprintf(fpdbg,"message size %d > buffer size %lu\n",clen,sizeof(cbuf));
         return(LAN_ERR_TOO_SHORT);
     }
 
@@ -2242,7 +2240,6 @@ int  lan_recv_sol( SOL_RSP_PKT *rsp )
    uchar rdata[MAX_BUFFER_SIZE];
    int  rlen, hlen;
    IPMI_HDR *phdr;
-   int fdoauth = 1;
    uchar *pdata;
    int itry;
    int flags; 
@@ -2250,7 +2247,6 @@ int  lan_recv_sol( SOL_RSP_PKT *rsp )
 
    phdr = &ipmi_hdr;
    rsp->data = rsdata;
-   fdoauth = 0; 
    hlen = SOL_HLEN;
    rlen = 0;
    if (fdebuglan)
