@@ -155,6 +155,8 @@ void ShowSDR(char *tag, uchar *sdr);
 int GetSDRRepositoryInfo(int *nret, int *fdev);
 int GetSensorThresholds(uchar sens_num, uchar *data);
 int GetSensorReading(uchar sens_num, void *psdr, uchar *sens_data);
+int GetSensorReadingFactors(uchar snum, uchar raw, int *m, int *b, int *  b_exp,
+            int *r, int *a);
 double RawToFloat(uchar raw, uchar *psdr);
 char *decode_entity_id(int id);
 char *get_unit_type(int iunits, int ibase, int imod, int fshort);
