@@ -155,8 +155,13 @@ typedef struct
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil serial";
+#else
+static char * progver   = "3.08";
 static char * progname  = "iserial";
+#endif
 static int    vend_id = 0;
 static int    prod_id = 0;
 static char   fdebug    = 0;
