@@ -73,8 +73,13 @@ typedef uint32_t   socklen_t;
 #define FRU_TYPE_COMPONENT  0x01
 #define FRU_TYPE_BASEBOARD  0x07
 
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil kontronoem";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ikontronoem";
+#endif
 const struct valstr ktc5520_post[] = {  /*from EAS*/
  { 0x0003, "Start POST Init" },
  { 0x0004, "Check CMOS" },
