@@ -436,8 +436,8 @@ static struct { int val; char *pstr; } mfgs[N_MFG] = {
     {VENDOR_QUANTA, "Quanta"}, /*=7244. */
     {VENDOR_MAGNUM, "Magnum Technologies"}, /*=5593. */
     {VENDOR_SUPERMICROX, "xSuperMicro"}, /* 47488. used by Winbond/SuperMicro*/
-    {VENDOR_HP,   "HP"},     /* 0x00000B for HP */
-    {VENDOR_DELL, "Dell"},    /*0x0002A2*/
+    {VENDOR_HP,   "HP"},     /* 0x00000B (11.) for HP */
+    {VENDOR_DELL, "Dell"},    /*0x0002A2 (674.) */
     {VENDOR_KONTRON,    "Kontron"},     /*=0x003A98, 15000.*/
     {VENDOR_SUPERMICRO, "SuperMicro"},  /*=0x002A7C, 10876. used in AOC-SIMSO*/
     {VENDOR_FUJITSU,    "Fujitsu-Siemens"}, /* 0x002880, 10368. */
